@@ -3,13 +3,9 @@ import shapely.geometry
 import shapely.ops
 import warnings
 import rdp
-import wrap_scour
-import os
 
 '''
 Methods for working with path and style data from svg files
-Written July 22, 2014
-Author: Gen Del Raye
 '''
 
 class nullpoly():
@@ -76,12 +72,9 @@ class Polygon:
     
     def overlaps(self, other):
         '''
-        Return whether the interior of a polygon intersects with the interior of another
-        See discussion on object.touches() in the Shapely User Manual 
-        (http://toblerity.org/shapely/manual.html) for more details.
+        Return whether the polygon intersects with other
         '''
-        return self.poly.intersects(other.poly) and not self.poly.touches(other.poly)
-#         return self.poly.overlaps(other.poly)
+        return self.poly.overlaps(other.poly)
     
     def union(self, other):
         '''
@@ -90,20 +83,11 @@ class Polygon:
         self.poly = self.poly.union(other.poly)
         
     def cascading_union(self, other_list):
-        '''
-        Return union of self.poly and multiple polygons in other_list
-        Shapely.ops.cascaded_union is preferred over poly.union because
-        the former is more efficient for calculating the union of multiple
-        polygons at once.
-        '''
         poly_list = [o.poly for o in other_list]
         poly_list.append(self.poly)
         self.poly = shapely.ops.cascaded_union(poly_list)
         
     def coords(self):
-        '''
-        Return the coordinates of the current polygon
-        '''
         try:
             return list(self.poly.exterior.coords)
         except AttributeError, e:
@@ -113,15 +97,9 @@ class Polygon:
                 return list(self.poly[0].exterior.coords)
         
     def buffer(self, distance):
-        '''
-        Expand the polygon by adding a 'buffer'
-        '''
         self.poly = self.poly.buffer(distance)
     
     def hull(self, other_list):
-        '''
-        Calculate the minimum convex hull of self.poly and the polygons in other_list
-        '''
         poly_coords = self.coords()
         for o in other_list:
             poly_coords.extend(o.coords())
@@ -232,31 +210,4 @@ def parse_style(stylestr):
     stylestr = stylestr.split(';') # Split by entry
     styledict = dict([(s.split(':')[0], s.split(':')[-1]) for s in stylestr])
     return styledict
-
-def optimize_svg(filename, outputname, encoding = 'utf-8', **kwargs):
-    '''
-    Use package Scour to optimize an svg rather than compress it
-    Inputs:
-        filename(str) - path of input svg (e.g. 'test/test_vector.svg')
-        outputname(str) - path of output svg (e.g. 'test/test_vector_opt.svg')
-        encoding(str) - encoding of the svg in filename. Defaults to utf-8
-        kwargs - additional arguments to wrap_scour.optimize. Default argument
-          names and values are given in optimize_tothe_max (these are the most
-          aggresive optimization procedures).
-    '''
-    optimize_tothe_max = {'strip_ids': True, 'shorten_ids': True, 'simple_colors': True, 
-                          'strip_comments': True, 'remove_metadata': True,
-                          'group_create': True, 'protect_ids_noninkscape': False, 
-                          'indent_type': None, 'keep_editor_data': False, 
-                          'renderer_workaround': False, 'style_to_xml': True, 
-                          'enable_viewboxing': True, 'digits': 5, 'embed_rasters': True, 
-                          'strip_xml_prolog': False, 'group_collapse': True
-                          }
-    optimize_tothe_max.update(kwargs)
-    wrap_scour.optimize(filename, outputname, **optimize_tothe_max)
-
-def get_kb(filename):
-    '''
-    Return size of the file 'filename' in KB.
-    '''
-    return os.path.getsize(filename)/1000.0
\ No newline at end of file
+# print 'Retained %d out of %d polygons' %(len(new_coords), len(path_coords))
\ No newline at end of file
